/*
 *	tags file symbol lookup
 *	Copyright
 *		(C) 1992 Joseph H. Allen
 *
 *	This file is part of JOE (Joe's Own Editor)
 */
#ifndef _JOE_UTAG_H
#define _JOE_UTAG_H 1

#ifdef EXTERN_CMD_C
__IDSTRING(rcsid_utag_h, "$MirOS: contrib/code/jupp/utag.h,v 1.6 2017/12/06 23:17:36 tg Exp $");
#endif

int utag(BW *bw);

#endif
